#
# spec file for package python-smmap
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-smmap
Version:        3.0.2
Release:        bp153.1.15
Summary:        A pure git implementation of a sliding window memory map manager
License:        BSD-2-Clause
URL:            https://github.com/gitpython-developers/smmap
Source:         https://files.pythonhosted.org/packages/source/s/smmap/smmap-%{version}.tar.gz
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
When reading from many possibly large files in a fashion similar to random
access, it is usually the fastest and most efficient to use memory maps.
Although memory maps have many advantages, they represent a very limited
system resource as every map uses one file descriptor, whose amount is
limited per process. On 32 bit systems, the amount of memory you can have
mapped at a time is naturally limited to theoretical 4GB of memory, which
may not be enough for some applications.

The documentation can be found here: http://packages.python.org/smmap

%prep
%setup -q -n smmap-%{version}
dos2unix README.md

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} nosetests-%{$python_bin_suffix} -v

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/*

%changelog
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.0.2
  * Add github actions
  * Remove basestring reference, no py2 support
  * Update badges to represent reality
  * Change required key to 2CF*, which seems to be the only good one
* Mon Mar 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- Install doc/license
- Sync the package with smmap2 to have the same fixes in
* Mon Mar 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.0.1:
  * Switched back to the smmap package name on PyPI and fixed the smmap2 mirror package (#44)
  * Fixed setup.py long_description rendering (#40)
- remove delete_platform_specific_test.patch (upstream)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Aug 15 2017 daniel.molkentin@suse.com
- Converted to python singlespec
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 0.9.0:
  * Fixed issue with resources never being freed as mmaps were
    never closed
  * Client counting is now done manually, instead of relying on
    pyton's reference count
- additional changes from version 0.8.5:
  * Fixed Python 3.0-3.3 regression, which also causes smmap to
    become about 3 times slower depending on the code path. It's
    related to this bug (http://bugs.python.org/issue15958), which
    was fixed in python 3.4
- additional changes from version 0.8.4:
  * Fixed Python 3 performance regression
- additional changes from version 0.8.3:
  * Cleaned up code and assured it works sufficiently well with
    python 3
- update project URL
- add fdupes as BuildRequires and call it after install
- add dependencies (nose, nosexcover) for the tests
- add delete_platform_specific_test.patch: fix tests on powerpc
- pass -q to the test to avoid spamming the build log
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Mar 14 2012 saschpe@suse.de
- Use upstream tarball
- Simplified macro usage
- Run testsuite
* Thu Jan 19 2012 alexandre@exatati.com.br
- Update to 0.8.2:
  - Sorry, no changelog yet.
* Wed Jul  6 2011 alexandre@exatati.com.br
- Initial package (0.8.1) for openSUSE.
